from collections.abc import Generator

from _typeshed import Incomplete

from .base import Base as Base

LOG: Incomplete

class Events(Base):
    base_url_path: str
    def subscribe(
        self,
        types,
        queue,
        filters: Incomplete | None = ...,
        filter_vars: Incomplete | None = ...,
    ) -> Generator[Incomplete, None, None]: ...



import sys
from logging import Logger
from typing import Dict, List, Literal, Type, Union

from .client import Client
from .exceptions import *

if sys.version_info >= (3, 0): ...
else: ...
LOG: Logger = ...

Json = Union[Dict[str, "Json"], List["Json"], int, str, float, bool, Type[None]]

HostService = Literal["Host", "Service"]

HostServiceComment = Union[Literal["Comment"], HostService]

HostServiceDowntime = Union[Literal["Downtime"], HostService]

ObjectType = Literal[
    "ApiListener",
    "ApiUser",
    "CheckCommand",
    "Arguments",
    "CheckerComponent",
    "CheckResultReader",
    "Comment",
    "CompatLogger",
    "Dependency",
    "Downtime",
    "Endpoint",
    "EventCommand",
    "ExternalCommandListener",
    "FileLogger",
    "GelfWriter",
    "GraphiteWriter",
    "Host",
    "HostGroup",
    "IcingaApplication",
    "IdoMySqlConnection",
    "IdoPgSqlConnection",
    "LiveStatusListener",
    "Notification",
    "NotificationCommand",
    "NotificationComponent",
    "OpenTsdbWriter",
    "PerfdataWriter",
    "ScheduledDowntime",
    "Service",
    "ServiceGroup",
    "StatusDataWriter",
    "SyslogLogger",
    "TimePeriod",
    "User",
    "UserGroup",
    "Zone",
]

class Base:

    base_url_path: str = ...

    def __init__(self, manager: Client) -> None: ...



from typing import Literal

from _typeshed import Incomplete

from .base import (Base, HostService, HostServiceComment, HostServiceDowntime,
                   Json)
from .exceptions import Icinga2ApiException as Icinga2ApiException

LOG: Incomplete

ExitStatus = Literal[0, 1, 2, 3]

class Actions(Base):
    base_url_path: str
    def process_check_result(
        self,
        object_type: HostService,
        name: str,
        exit_status: ExitStatus,
        plugin_output: str,
        performance_data: Incomplete | None = ...,
        check_command: Incomplete | None = ...,
        check_source: str | None = ...,
        execution_start: int | None = ...,
        execution_end: int | None = ...,
        ttl: int | None = ...,
        filters: Incomplete | None = ...,
        filter_vars: Incomplete | None = ...,
    ) -> Json: ...
    def reschedule_check(
        self,
        object_type: HostService,
        filters,
        filter_vars: Incomplete | None = ...,
        next_check: Incomplete | None = ...,
        force_check: bool = ...,
    ) -> Json: ...
    def send_custom_notification(
        self,
        object_type: HostService,
        filters,
        author,
        comment,
        filter_vars: Incomplete | None = ...,
        force: bool = ...,
    ) -> Json: ...
    def delay_notification(
        self,
        object_type: HostService,
        filters,
        timestamp,
        filter_vars: Incomplete | None = ...,
    ) -> Json: ...
    def acknowledge_problem(
        self,
        object_type: HostService,
        filters,
        author,
        comment,
        filter_vars: Incomplete | None = ...,
        expiry: Incomplete | None = ...,
        sticky: Incomplete | None = ...,
        notify: Incomplete | None = ...,
        persistent: Incomplete | None = ...,
    ) -> Json: ...
    def remove_acknowledgement(
        self, object_type: ObjectType, filters, filter_vars: Incomplete | None = ...
    ) -> Json: ...
    def add_comment(
        self,
        object_type: HostService,
        filters,
        author,
        comment,
        filter_vars: Incomplete | None = ...,
    ) -> Json: ...
    def remove_comment(
        self,
        object_type: HostServiceComment,
        name: Incomplete | None = ...,
        filters: Incomplete | None = ...,
        filter_vars: Incomplete | None = ...,
    ) -> Json: ...
    def schedule_downtime(
        self,
        object_type: HostService,
        filters,
        author,
        comment,
        start_time,
        end_time,
        duration,
        filter_vars: Incomplete | None = ...,
        fixed: Incomplete | None = ...,
        all_services: Incomplete | None = ...,
        trigger_name: Incomplete | None = ...,
        child_options: Incomplete | None = ...,
    ) -> Json: ...
    def remove_downtime(
        self,
        object_type: HostServiceDowntime,
        name: Incomplete | None = ...,
        filters: Incomplete | None = ...,
        filter_vars: Incomplete | None = ...,
    ) -> Json: ...
    def shutdown_process(self) -> Json: ...
    def restart_process(self) -> Json: ...
    def generate_ticket(self, host_common_name) -> Json: ...



from logging import Logger

from icinga2apic.objects import Objects

from .actions import Actions

LOG: Logger = ...

class Client:

    actions: Actions

    objects: Objects

    def __init__(
        self,
        url: str | None = ...,
        username: str | None = ...,
        password: str | None = ...,
        timeout: int | None = ...,
        certificates: str | None = ...,
        key: str | None = ...,
        ca_certificate: str | None = ...,
        config_file: str | None = ...,
    ) -> None: ...



from _typeshed import Incomplete

class Icinga2ApiException(Exception):
    error: Incomplete
    def __init__(self, error) -> None: ...

class Icinga2ApiRequestException(Icinga2ApiException):
    response: Incomplete
    def __init__(self, error, response) -> None: ...

class Icinga2ApiConfigFileException(Exception):
    error: Incomplete
    def __init__(self, error) -> None: ...



from typing import List, Union

from _typeshed import Incomplete as Incomplete

from .base import Base, Json, ObjectType

LOG: Incomplete

class Objects(Base):
    base_url_path: str
    def get(
        self,
        object_type: ObjectType,
        name: str,
        attrs: Union[Incomplete, None] = ...,
        joins: Union[Incomplete, None] = ...,
    ) -> Json: ...
    def list(
        self,
        object_type: ObjectType,
        name: str | None = ...,
        attrs: List[str] | None = ...,
        filters: str | None = ...,
        filter_vars: Union[Incomplete, None] = ...,
        joins: bool | List[str] | None = ...,
    ) -> Json: ...
    def create(
        self,
        object_type: ObjectType,
        name: str,
        templates: Union[Incomplete, None] = ...,
        attrs: Union[Incomplete, None] = ...,
    ) -> Json: ...
    def update(self, object_type: ObjectType, name: str, attrs) -> Json: ...
    def delete(
        self,
        object_type: ObjectType,
        name: Union[Incomplete, None] = ...,
        filters: Union[Incomplete, None] = ...,
        filter_vars: Union[Incomplete, None] = ...,
        cascade: bool = ...,
    ) -> Json: ...



from _typeshed import Incomplete

from .exceptions import \
    Icinga2ApiConfigFileException as Icinga2ApiConfigFileException

class ClientConfigFile:
    file_name: Incomplete
    section: str
    url: Incomplete
    username: Incomplete
    password: Incomplete
    certificate: Incomplete
    key: Incomplete
    ca_certificate: Incomplete
    timeout: Incomplete
    def __init__(self, file_name) -> None: ...
    def check_access(self): ...
    def parse(self) -> None: ...
